==> kartofel-1.1.tar.gz: kartofel-1.1/config.h <==
//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef KARTOFEL_CONFIG_H
#define KARTOFEL_CONFIG_H

#define VERSION "1.1"

#define HIGH_SCORES_FILENAME "./kartofel.txt"
#define SCORE_SUBMISSION_URL "http://kartofel.jfedor.org/ksc.php"

#define SOUND_MENU_NAV_FILENAME "sounds/click02.wav"
#define SOUND_MENU_CLICK_FILENAME "sounds/click01.wav"
#define SOUND_ROTATE_FILENAME "sounds/click03.wav"
#define SOUND_START_FILENAME "sounds/click03.wav"
#define SOUND_CRASH_FILENAME "sounds/sound_crash.wav"
#define SOUND_DOT_LIT_FILENAME "sounds/sound_dot_lit.wav"
#define SOUND_LEVEL_SUCCESS_FILENAME "sounds/sound_level_success.wav"
#define SOUND_OUT_OF_TIME_FILENAME "sounds/sound_out_of_time.wav"
#define SOUND_ENTER_NAME_RETURN_FILENAME "sounds/click01.wav"

#define MENU_FONT_FILENAME "fonts/Cyklop-Regular.ttf"
#define MENU_TITLE_FONT_FILENAME "fonts/Cyklop-Regular.ttf"
#define INFO_FONT_FILENAME "fonts/FreeSans.ttf"
#define INFO_FONT_SMALL_FILENAME "fonts/FreeSans.ttf"
#define MSG_FONT_FILENAME "fonts/Cyklop-Regular.ttf"

#define MUSIC_FILENAME "music/moonlight.mp3"
#define MENU_BACKGROUND_IMAGE_FILENAME "images/Cliffs-1024x768.png"
#define ICON_FILENAME "images/icon32x32.png"
#define LEVELS_FILENAME_PREFIX "levels/"

#endif  // KARTOFEL_CONFIG_H

==> kartofel-1.2.tar.gz: kartofel-1.2/config.h <==
//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#ifndef KARTOFEL_CONFIG_H
#define KARTOFEL_CONFIG_H

#define VERSION "1.2"

#define HIGH_SCORES_FILENAME "./kartofel.txt"
#define SCORE_SUBMISSION_URL "http://kartofel.jfedor.org/ksc.php"

#define SOUND_MENU_NAV_FILENAME "sounds/click02.wav"
#define SOUND_MENU_CLICK_FILENAME "sounds/click01.wav"
#define SOUND_ROTATE_FILENAME "sounds/click03.wav"
#define SOUND_START_FILENAME "sounds/click03.wav"
#define SOUND_CRASH_FILENAME "sounds/sound_crash.wav"
#define SOUND_DOT_LIT_FILENAME "sounds/sound_dot_lit.wav"
#define SOUND_LEVEL_SUCCESS_FILENAME "sounds/sound_level_success.wav"
#define SOUND_OUT_OF_TIME_FILENAME "sounds/sound_out_of_time.wav"
#define SOUND_ENTER_NAME_RETURN_FILENAME "sounds/click01.wav"

#define MENU_FONT_FILENAME "fonts/Cyklop-Regular.ttf"
#define MENU_TITLE_FONT_FILENAME "fonts/Cyklop-Regular.ttf"
#define INFO_FONT_FILENAME "fonts/FreeSans.ttf"
#define INFO_FONT_SMALL_FILENAME "fonts/FreeSans.ttf"
#define MSG_FONT_FILENAME "fonts/Cyklop-Regular.ttf"

#define MUSIC_FILENAME "music/moonlight.ogg"
#define MENU_BACKGROUND_IMAGE_FILENAME "images/Cliffs-1024x768.png"
#define ICON_FILENAME "images/icon32x32.png"
#define LEVELS_FILENAME_PREFIX "levels/"

#endif  // KARTOFEL_CONFIG_H
